@@ -52,7 +52,7 @@
 #include "AboutDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -217,4 +217,4 @@ AboutDlg::showHowToCiteTab()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
