@@ -43,7 +43,7 @@
 #include "ui_AboutDlg.h"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -81,4 +81,4 @@ class AboutDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
