@@ -52,7 +52,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -475,4 +475,4 @@ AnalysisPreferencesDlg::analysisPreferences()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
