@@ -66,7 +66,7 @@
 #include "../nongui/globals.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -242,4 +242,4 @@ Application::setProgramWindow(ProgramWindow *program_window_p)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
