@@ -47,7 +47,7 @@
 /////////////////////// Local includes
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace minexpert
@@ -98,4 +98,4 @@ class Application : public QApplication
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
