@@ -49,12 +49,12 @@
 /////////////////////// Local includes
 #include "BaseColorMapPlotCompositeWidget.hpp"
 #include "BaseColorMapPlotWnd.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "MsFragmentationSpecDlg.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 #include "ProgramWindow.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -301,7 +301,7 @@ BaseColorMapPlotCompositeWidget::addColorMap(
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = libmassgui::ColorSelector::getColor(true);
+    local_color = libXpertMassGui::ColorSelector::getColor(true);
 
   // Contrary to what we do with graphs, we cannot stuff more than one color map
   // into a color map plot, so just add a new plot.
@@ -448,4 +448,4 @@ BaseColorMapPlotCompositeWidget::saveMatrixAsMatrixToTextFile(bool detailed)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
