@@ -56,7 +56,7 @@
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -154,4 +154,4 @@ class BaseColorMapPlotCompositeWidget : public BasePlotCompositeWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
