@@ -43,10 +43,10 @@
 /////////////////////// Local includes
 #include "BaseColorMapPlotWnd.hpp"
 #include "ProgramWindow.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -150,7 +150,7 @@ BaseColorMapPlotWnd::finalNewColorMapPlotConfiguration(
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = libmassgui::ColorSelector::getRandomColor();
+    local_color = libXpertMassGui::ColorSelector::getRandomColor();
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
 
@@ -312,4 +312,4 @@ BaseColorMapPlotWnd::integrateToDtRt(QCPAbstractPlottable *parent_plottable_p,
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
