@@ -49,7 +49,7 @@
 #include "BaseColorMapPlotCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -122,4 +122,4 @@ class BaseColorMapPlotWnd : public BasePlotWnd
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
