@@ -48,13 +48,13 @@
 
 /////////////////////// Local includes
 #include "BasePlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "MsFragmentationSpecDlg.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 #include "ProcessingFlowViewerDlg.hpp"
 #include "ProgramWindow.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -1629,4 +1629,4 @@ BasePlotCompositeWidget::setSampleNameColor(const QColor &color)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
