@@ -55,7 +55,7 @@
 #include "MzIntegrationParamsDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -275,4 +275,4 @@ class BasePlotCompositeWidget : public QWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
