@@ -54,7 +54,7 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -1639,4 +1639,4 @@ BasePlotWnd::removeEmptyPlotWidgets()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
