@@ -54,7 +54,7 @@
 #include "PlotAreaOverlay.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -221,4 +221,4 @@ class BasePlotWnd : public QMainWindow
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
