@@ -50,12 +50,12 @@
 /////////////////////// Local includes
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "BaseTracePlotWnd.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "ProgramWindow.hpp"
 #include "LabelledNumberLineEditAction.hpp"
 #include "Application.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -359,7 +359,7 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = libmassgui::ColorSelector::getColor(true);
+    local_color = libXpertMassGui::ColorSelector::getColor(true);
 
   // We have to verify if there is a destination policy for this composite plot
   // widget. There are different situations.
@@ -1289,4 +1289,4 @@ BaseTracePlotCompositeWidget::savePeakListToFile()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
