@@ -55,7 +55,7 @@
 #include "SavitzkyGolayFilterParamsDlg.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -140,4 +140,4 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
