@@ -47,10 +47,10 @@
 /////////////////////// Local includes
 #include "BaseTracePlotWnd.hpp"
 #include "ProgramWindow.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -243,7 +243,7 @@ BaseTracePlotWnd::finalNewTracePlotConfiguration(
   // Get color from the available colors, or if none is available, create one
   // randomly without requesting the user to select one from QColorDialog.
   if(!local_color.isValid())
-    local_color = libmassgui::ColorSelector::getRandomColor();
+    local_color = libXpertMassGui::ColorSelector::getRandomColor();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
@@ -492,4 +492,4 @@ BaseTracePlotWnd::duplicateTracePlot(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
