@@ -49,7 +49,7 @@
 #include "BaseTracePlotCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -117,4 +117,4 @@ class BaseTracePlotWnd : public BasePlotWnd
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
