@@ -42,7 +42,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -195,4 +195,4 @@ ConsoleWnd::show()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
