@@ -43,7 +43,7 @@
 /////////////////////// Local includes
 #include "ui_ConsoleWnd.h"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -87,4 +87,4 @@ class ConsoleWnd : public QMainWindow
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
