@@ -46,7 +46,7 @@
 #include "BasePlotWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -717,4 +717,4 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
