@@ -50,7 +50,7 @@
 #include "DataPlottableNode.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -108,4 +108,4 @@ class DataPlottableTree
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
