@@ -50,7 +50,7 @@
 #include "BaseColorMapPlotWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -689,4 +689,4 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
