@@ -51,7 +51,7 @@
 #include "BaseColorMapPlotCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -81,4 +81,4 @@ class DriftSpecMassSpecColorMapPlotCompositeWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
