@@ -48,12 +48,12 @@
 #include "ProgramWindow.hpp"
 #include "DriftSpecMassSpecColorMapWnd.hpp"
 #include "DriftSpecMassSpecColorMapPlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -453,4 +453,4 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
