@@ -52,7 +52,7 @@
 #include "DriftSpecTracePlotWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -851,4 +851,4 @@ DriftSpecTracePlotCompositeWidget::craftAnalysisStanza(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
