@@ -52,7 +52,7 @@
 #include "BaseTracePlotCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -91,4 +91,4 @@ class DriftSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
