@@ -47,13 +47,13 @@
 #include "ProgramWindow.hpp"
 #include "DriftSpecTracePlotWnd.hpp"
 #include "DriftSpecTracePlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 #include "TaskMonitorWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -465,4 +465,4 @@ DriftSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *parent_plottable_p,
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
