@@ -47,7 +47,7 @@
 #include "DriftSpecTracePlotCompositeWidget.hpp"
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToDt.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -104,4 +104,4 @@ class DriftSpecTracePlotWnd : public BaseTracePlotWnd
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
