@@ -47,7 +47,7 @@
 #include "LabelledDoubleSpinBoxAction.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -117,4 +117,4 @@ LabelledDoubleSpinBoxAction::getValue() const
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
