@@ -46,7 +46,7 @@
 /////////////////////// Local includes
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -75,4 +75,4 @@ class LabelledDoubleSpinBoxAction : public QWidgetAction
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
