@@ -47,7 +47,7 @@
 #include "LabelledNumberLineEditAction.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -155,4 +155,4 @@ LabelledNumberLineEditAction::getValue() const
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
