@@ -47,7 +47,7 @@
 /////////////////////// Local includes
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -85,4 +85,4 @@ class LabelledNumberLineEditAction : public QWidgetAction
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
