@@ -47,8 +47,8 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/PeakCentroid.hpp>
-#include <libmass/MassDataCborMassSpectrumHandler.hpp>
+#include <libXpertMass/PeakCentroid.hpp>
+#include <libXpertMass/MassDataCborMassSpectrumHandler.hpp>
 
 
 /////////////////////// pappsomspp includes
@@ -66,12 +66,12 @@
 #include "MassSpecTracePlotWidget.hpp"
 #include "MassSpecTracePlotWnd.hpp"
 #include "ProgramWindow.hpp"
-#include <libmass/MassPeakShaperConfig.hpp>
-#include <libmass/MassPeakShaper.hpp>
-#include "ColorSelector.hpp"
+#include <libXpertMass/MassPeakShaperConfig.hpp>
+#include <libXpertMass/MassPeakShaper.hpp>
+#include <libXpertMassGui/ColorSelector.hpp>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -512,21 +512,19 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
   // At this point use our facility to compute the Gaussian trace.
 
   // This was the old version.
-  // libmass::MassPeakShaperConfig mass_peak_shaper_config(
-  // 0, fwhm, "H", 1, 500, 0, 1, libmass::MassPeakShapeType::GAUSSIAN);
+  // libXpertMass::MassPeakShaperConfig mass_peak_shaper_config(
+  // 0, fwhm, "H", 1, 500, 0, 1, libXpertMass::MassPeakShapeType::GAUSSIAN);
 
-  libmass::MassPeakShaperConfig mass_peak_shaper_config;
+  libXpertMass::MassPeakShaperConfig mass_peak_shaper_config;
   mass_peak_shaper_config.setResolution(0);
   mass_peak_shaper_config.setFwhm(fwhm);
-  mass_peak_shaper_config.setIonizationFormula("H");
   mass_peak_shaper_config.setPointCount(200);
   mass_peak_shaper_config.setReferencePeakMz(most_intense_datapoint.x);
   mass_peak_shaper_config.setMzStep(0);
-  mass_peak_shaper_config.setNormFactor(1);
   mass_peak_shaper_config.setMassPeakShapeType(
-    libmass::MassPeakShapeType::GAUSSIAN);
+    libXpertMass::MassPeakShapeType::GAUSSIAN);
 
-  libmass::MassPeakShaper mass_peak_shaper(
+  libXpertMass::MassPeakShaper mass_peak_shaper(
     gaussian_mu, A, mass_peak_shaper_config);
 
   mass_peak_shaper.computePeakShape();
@@ -539,7 +537,7 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
 
   // qDebug() << "Going to write this trace:" << fit_trace.toString();
 
-  libmass::MassDataCborMassSpectrumHandler cbor_handler(this, fit_trace);
+  libXpertMass::MassDataCborMassSpectrumHandler cbor_handler(this, fit_trace);
 
   QByteArray byte_array;
 
@@ -880,7 +878,8 @@ MassSpecTracePlotCompositeWidget::plotWidgetKeyReleaseEvent(
 }
 
 void
-MassSpecTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(const pappso::BasePlotContext &context)
+MassSpecTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(const pappso::BasePlotContext
+&context)
 {
   // qDebug();
 
@@ -1282,7 +1281,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
   // one randomly without requesting the user to select one from
   // QColorDialog.
   if(!local_color.isValid())
-    local_color = libmassgui::ColorSelector::getColor(true);
+    local_color = libXpertMassGui::ColorSelector::getColor(true);
 
   // qDebug().noquote() << "The processing flow:" <<
   // processing_flow.toString();
@@ -1964,4 +1963,4 @@ MassSpecTracePlotCompositeWidget::
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
