@@ -50,7 +50,7 @@
 #include "BaseTracePlotCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -118,4 +118,4 @@ class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
