@@ -43,7 +43,7 @@
 /////////////////////// Local includes
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -63,4 +63,4 @@ class MassSpecTracePlotWidget : public pappso::BaseTracePlotWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
