@@ -41,7 +41,7 @@
 
 
 /////////////////////// libmass includes
-#include <libmass/MassDataCborMassSpectrumHandler.hpp>
+#include <libXpertMass/MassDataCborMassSpectrumHandler.hpp>
 #include <pappsomspp/massspectrum/massspectrum.h>
 #include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
 #include <pappsomspp/msrun/msrundatasettree.h>
@@ -58,10 +58,10 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 #include "TaskMonitorWnd.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -579,7 +579,7 @@ void
 MassSpecTracePlotWnd::handleReceivedData(const QByteArray &byte_array)
 {
 
-  libmass::MassDataCborMassSpectrumHandler cbor_handler(this);
+  libXpertMass::MassDataCborMassSpectrumHandler cbor_handler(this);
 
   if(!cbor_handler.readByteArray(byte_array))
     {
@@ -683,7 +683,7 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   stream >> plot_color;
 
   if(!plot_color.isValid())
-    plot_color = libmassgui::ColorSelector::getColor(true);
+    plot_color = libXpertMassGui::ColorSelector::getColor(true);
 
   // Now we should document the mz integration parameters in the processing flow
   // that is mapped to the graph in such a way that the default mz integration
@@ -718,4 +718,4 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 } // namespace minexpert
 
 
-} // namespace msxps
+} // namespace MsXpS
