@@ -54,7 +54,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -407,4 +407,4 @@ MsFragmentationSpecDlg::applyPushButtonClicked()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
