@@ -52,7 +52,7 @@
 #include "../nongui/MsFragmentationSpec.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -108,4 +108,4 @@ class MsFragmentationSpecDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
