@@ -35,7 +35,7 @@
 #include "MsRunDataSetTableView.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -59,4 +59,4 @@ MsRunDataSetTableView::~MsRunDataSetTableView()
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
