@@ -35,7 +35,7 @@
 #include "MsRunDataSetTableViewItem.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -118,4 +118,4 @@ MsRunDataSetTableViewItem::getQualifiedMassSpectrum() const
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
