@@ -47,7 +47,7 @@
 #include "MsRunDataSetTableViewModel.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -86,4 +86,4 @@ class MsRunDataSetTableViewItem
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
