@@ -51,7 +51,7 @@
 #include "MsRunDataSetTableViewItem.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -366,7 +366,7 @@ MsRunDataSetTableViewModel::setupModelData(
         {
           QVariant ion_mobility_variant_value =
             qualified_mass_spectrum_csp->getParameterValue(
-              pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+              pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
           if(ion_mobility_variant_value.isValid())
             {
@@ -465,4 +465,4 @@ MsRunDataSetTableViewModel::setupModelData(
 }
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
