@@ -49,7 +49,7 @@
 /////////////////////// Local includes
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -109,4 +109,4 @@ class MsRunDataSetTableViewModel : public QAbstractItemModel
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
