@@ -49,7 +49,7 @@
 #include "../nongui/ProcessingStep.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -1406,4 +1406,4 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
 }
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
