@@ -56,7 +56,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -615,7 +615,7 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
         {
           QVariant ion_mobility_variant_value =
             qualified_mass_spectrum_csp->getParameterValue(
-              pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+              pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
           if(ion_mobility_variant_value.isValid())
             {
@@ -904,4 +904,4 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
