@@ -52,7 +52,7 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -601,4 +601,4 @@ MsRunProbeInfoViewerDlg::validateData()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
