@@ -50,7 +50,7 @@
 #include "../nongui/MassDataIntegrator.hpp"
 #include "../nongui/MsRunProber.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -120,4 +120,4 @@ class MsRunProbeInfoViewerDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
