@@ -56,15 +56,15 @@
 
 
 int MsRunProbeTaskMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunProbeTask>(
-    "msxps::minexpert::MsRunProbeTask");
+  qRegisterMetaType<MsXpS::minexpert::MsRunProbeTask>(
+    "MsXpS::minexpert::MsRunProbeTask");
 
 int MsRunProbeTaskSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunProbeTaskSPtr>(
-    "msxps::minexpert::MsRunProbeTaskSPtr");
+  qRegisterMetaType<MsXpS::minexpert::MsRunProbeTaskSPtr>(
+    "MsXpS::minexpert::MsRunProbeTaskSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -135,4 +135,4 @@ MsRunProbeTask::probeMsRun(MsRunProbeTask *ms_run_probe_task_p,
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
