@@ -49,7 +49,7 @@
 /////////////////////// Local includes
 #include "../nongui/MsRunProber.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -85,11 +85,11 @@ typedef std::shared_ptr<MsRunProbeTask> MsRunProbeTaskSPtr;
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunProbeTask)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunProbeTask)
 extern int MsRunProbeTaskMetaTypeId;
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunProbeTaskSPtr)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunProbeTaskSPtr)
 extern int MsRunProbeTaskSPtrMetaTypeId;
