@@ -57,15 +57,15 @@
 
 
 int MsRunReadTaskMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunReadTask>(
-    "msxps::minexpert::MsRunReadTask");
+  qRegisterMetaType<MsXpS::minexpert::MsRunReadTask>(
+    "MsXpS::minexpert::MsRunReadTask");
 
 int MsRunReadTaskSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunReadTaskSPtr>(
-    "msxps::minexpert::MsRunReadTaskSPtr");
+  qRegisterMetaType<MsXpS::minexpert::MsRunReadTaskSPtr>(
+    "MsXpS::minexpert::MsRunReadTaskSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -145,4 +145,4 @@ MsRunReadTask::readMsRunData(MsRunReadTask *ms_run_read_task_p,
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
