@@ -45,7 +45,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -150,4 +150,4 @@ MsRunSelectorDlg::reject()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
