@@ -46,7 +46,7 @@
 #include "ui_MsRunSelectorDlg.h"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -85,4 +85,4 @@ class MsRunSelectorDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
