@@ -46,7 +46,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -341,4 +341,4 @@ MzIntegrationParamsDlg::applyPushButtonClicked()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
