@@ -51,7 +51,7 @@
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -106,4 +106,4 @@ class MzIntegrationParamsDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
