@@ -49,11 +49,11 @@
 #include "../nongui/MsRunDataSet.hpp"
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "ProgramWindow.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -241,7 +241,7 @@ OpenMsRunDataSetsDlg::changePlottingColor()
 
   // We need to let the user select a color.
 
-  libmassgui::ColorSelector color_selector;
+  libXpertMassGui::ColorSelector color_selector;
 
   QColor new_color = color_selector.chooseColor();
 
@@ -477,7 +477,7 @@ OpenMsRunDataSetsDlg::removeMsRunDataSet(
 
   QColor color;
   color = brush.color();
-  libmassgui::ColorSelector::releaseColor(color);
+  libXpertMassGui::ColorSelector::releaseColor(color);
 
   m_msRunDataSetListWidgetItemMap.erase(ms_run_data_set_csp);
 
@@ -746,4 +746,4 @@ OpenMsRunDataSetsDlg::colorFromMsRunDataSet(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
