@@ -51,7 +51,7 @@
 #include "MsRunDataSetTableViewWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -157,4 +157,4 @@ class OpenMsRunDataSetsDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
