@@ -47,7 +47,7 @@
 #include "PlotAreaOverlay.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -116,4 +116,4 @@ PlotAreaOverlay::paintEvent([[maybe_unused]] QPaintEvent *paint_event)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
