@@ -43,7 +43,7 @@
 #include <QEvent>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -78,4 +78,4 @@ class PlotAreaOverlay : public QWidget
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
