@@ -31,9 +31,9 @@
  */
 
 /////////////////////// StdLib includes
-#include <libmassgui/IsotopicClusterGeneratorDlg.hpp>
-#include <libmassgui/IsotopicClusterShaperDlg.hpp>
-#include <libmass/MassDataCborBaseHandler.hpp>
+#include <libXpertMassGui/IsotopicClusterGeneratorDlg.hpp>
+#include <libXpertMassGui/IsotopicClusterShaperDlg.hpp>
+#include <libXpertMass/MassDataCborBaseHandler.hpp>
 #include <iostream>
 #include <cstdio>
 #include <iomanip>
@@ -61,8 +61,8 @@
 #include <pappsomspp/msfile/msfileaccessor.h>
 
 /////////////////////// Local includes
-#include <libmass/MassDataClient.hpp>
-#include <libmass/MassDataServer.hpp>
+#include <libXpertMass/MassDataClient.hpp>
+#include <libXpertMass/MassDataServer.hpp>
 
 #include "Application.hpp"
 #include "ProgramWindow.hpp"
@@ -79,7 +79,7 @@
 #include "vendor/BrukerBafAsciiMsRunLoader.hpp"
 #include "XyMsRunLoader.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace minexpert
@@ -1974,24 +1974,24 @@ ProgramWindow::createMenusAndActions()
       {
 
         mp_clientServerConfigDlg =
-          new libmassgui::MassDataClientServerConfigDlg(
+          new libXpertMassGui::MassDataClientServerConfigDlg(
             this, m_applicationName, "Client-server configuration");
         // At this point, make the connections with the signals provided by
         // the configuration dialog window.
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::startServerSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::startServerSignal,
                 this,
                 &ProgramWindow::startServer);
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::stopServerSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::stopServerSignal,
                 this,
                 &ProgramWindow::stopServer);
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::startClientSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::startClientSignal,
                 this,
                 &ProgramWindow::startClient);
         connect(mp_clientServerConfigDlg,
-                &libmassgui::MassDataClientServerConfigDlg::stopClientSignal,
+                &libXpertMassGui::MassDataClientServerConfigDlg::stopClientSignal,
                 this,
                 &ProgramWindow::stopClient);
       }
@@ -2169,11 +2169,11 @@ ProgramWindow::showXicExtractionWnd()
 void
 ProgramWindow::showIsotopicClusterGeneratorDlg()
 {
-  mp_isotopicClusterGeneratorDlg = new libmassgui::IsotopicClusterGeneratorDlg(
+  mp_isotopicClusterGeneratorDlg = new libXpertMassGui::IsotopicClusterGeneratorDlg(
     this, m_applicationName, "Isotopic cluster generator");
 
   connect(mp_isotopicClusterGeneratorDlg,
-          &libmassgui::IsotopicClusterGeneratorDlg::displayMassSpectrumSignal,
+          &libXpertMassGui::IsotopicClusterGeneratorDlg::displayMassSpectrumSignal,
           [this](const QString &title,
                  const QByteArray &color_byte_array,
                  pappso::TraceCstSPtr trace) {
@@ -2190,11 +2190,11 @@ ProgramWindow::showIsotopicClusterGeneratorDlg()
 void
 ProgramWindow::showIsotopicClusterShaperDlg()
 {
-  mp_isotopicClusterShaperDlg = new libmassgui::IsotopicClusterShaperDlg(
+  mp_isotopicClusterShaperDlg = new libXpertMassGui::IsotopicClusterShaperDlg(
     this, m_applicationName, "Isotopic cluster shaper");
 
   connect(mp_isotopicClusterShaperDlg,
-          &libmassgui::IsotopicClusterShaperDlg::displayMassSpectrumSignal,
+          &libXpertMassGui::IsotopicClusterShaperDlg::displayMassSpectrumSignal,
           [this](const QString &title,
                  const QByteArray &color_byte_array,
                  pappso::TraceCstSPtr trace) {
@@ -2313,7 +2313,7 @@ ProgramWindow::startServer()
   if(mpa_massDataServer != nullptr)
     delete mpa_massDataServer;
 
-  mpa_massDataServer = new libmass::MassDataServer(this);
+  mpa_massDataServer = new libXpertMass::MassDataServer(this);
 
   if(mpa_massDataServer != nullptr)
     {
@@ -2337,8 +2337,8 @@ ProgramWindow::startServer()
   QString ip_address = mpa_massDataServer->serverAddress().toString();
   int port_number    = mpa_massDataServer->serverPort();
 
-  libmassgui::MassDataClientServerConfigDlg *sender_p =
-    static_cast<libmassgui::MassDataClientServerConfigDlg *>(QObject::sender());
+  libXpertMassGui::MassDataClientServerConfigDlg *sender_p =
+    static_cast<libXpertMassGui::MassDataClientServerConfigDlg *>(QObject::sender());
 
   sender_p->updateClientConfigurationData(ip_address, port_number);
 
@@ -2367,7 +2367,7 @@ ProgramWindow::startClient(const QString &ip_address,
   if(mpa_massDataClient != nullptr)
     delete mpa_massDataClient;
 
-  mpa_massDataClient = new libmass::MassDataClient(
+  mpa_massDataClient = new libXpertMass::MassDataClient(
     ip_address, port_number, connection_frequency, this);
 
   if(mpa_massDataClient != nullptr)
@@ -2376,7 +2376,7 @@ ProgramWindow::startClient(const QString &ip_address,
       // dialog display the errors.
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::reportErrorSignal,
+              &libXpertMass::MassDataClient::reportErrorSignal,
               [this](const QString &error) {
                 qDebug();
                 if(mp_clientServerConfigDlg)
@@ -2384,14 +2384,14 @@ ProgramWindow::startClient(const QString &ip_address,
               });
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::newDataSignal,
+              &libXpertMass::MassDataClient::newDataSignal,
               [&](const QByteArray &byte_array) {
                 qDebug() << "Received new data of size:" << byte_array.size();
                 dispatchReceivedData(byte_array);
               });
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::hostFoundSignal,
+              &libXpertMass::MassDataClient::hostFoundSignal,
               [this]() {
                 if(mp_clientServerConfigDlg)
                   mp_clientServerConfigDlg->message("The remote host was found",
@@ -2399,7 +2399,7 @@ ProgramWindow::startClient(const QString &ip_address,
               });
 
       connect(mpa_massDataClient,
-              &libmass::MassDataClient::connectedSignal,
+              &libXpertMass::MassDataClient::connectedSignal,
               [this]() {
                 if(mp_clientServerConfigDlg)
                   mp_clientServerConfigDlg->message(
@@ -2430,18 +2430,18 @@ ProgramWindow::dispatchReceivedData(const QByteArray &byte_array)
   // determine what kind of data it contains. Depending on the data type, the
   // data are dispatched to the proper window.
 
-  libmass::MassDataType mass_data_type =
-    libmass::MassDataCborBaseHandler::readMassDataType(byte_array);
+  libXpertMass::MassDataType mass_data_type =
+    libXpertMass::MassDataCborBaseHandler::readMassDataType(byte_array);
 
   qDebug() << "Mass data type:" << (int)mass_data_type;
 
-  if(mass_data_type == libmass::MassDataType::UNSET)
+  if(mass_data_type == libXpertMass::MassDataType::UNSET)
     {
-      qDebug() << "The mass data type is libmass::MassDataType::UNSET";
+      qDebug() << "The mass data type is libXpertMass::MassDataType::UNSET";
     }
-  else if(mass_data_type == libmass::MassDataType::MASS_SPECTRUM)
+  else if(mass_data_type == libXpertMass::MassDataType::MASS_SPECTRUM)
     {
-      qDebug() << "The mass data type is libmass::MassDataType::MASS_SPECTRUM";
+      qDebug() << "The mass data type is libXpertMass::MassDataType::MASS_SPECTRUM";
 
       mp_massSpecPlotWnd->handleReceivedData(byte_array);
     }
@@ -2468,4 +2468,4 @@ ProgramWindow::massDataToBeServed(const QByteArray &byte_array)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
