@@ -79,12 +79,12 @@
 
 #include "ConsoleWnd.hpp"
 
-#include <libmassgui/includes/libmassgui/IsotopicClusterGeneratorDlg.hpp>
-#include <libmassgui/includes/libmassgui/IsotopicClusterShaperDlg.hpp>
+#include <libXpertMassGui/IsotopicClusterGeneratorDlg.hpp>
+#include <libXpertMassGui/IsotopicClusterShaperDlg.hpp>
 
-#include <libmass/MassDataServer.hpp>
-#include <libmass/MassDataClient.hpp>
-#include <libmassgui/includes/libmassgui/MassDataClientServerConfigDlg.hpp>
+#include <libXpertMass/MassDataServer.hpp>
+#include <libXpertMass/MassDataClient.hpp>
+#include <libXpertMassGui/MassDataClientServerConfigDlg.hpp>
 
 
 #include "../nongui/AnalysisPreferences.hpp"
@@ -101,7 +101,7 @@
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToRtDt.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -380,11 +380,11 @@ class ProgramWindow : public QMainWindow
 
   ConsoleWnd *mp_consoleWnd = nullptr;
 
-  libmassgui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg =
+  libXpertMassGui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg =
     nullptr;
-  libmassgui::IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
+  libXpertMassGui::IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
 
-  libmassgui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg = nullptr;
+  libXpertMassGui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg = nullptr;
 
   AnalysisPreferencesDlg *mp_analysisPreferencesDlg = nullptr;
 
@@ -394,8 +394,8 @@ class ProgramWindow : public QMainWindow
 
   AnalysisPreferences *mpa_analysisPreferences = nullptr;
 
-  libmass::MassDataClient *mpa_massDataClient = nullptr;
-  libmass::MassDataServer *mpa_massDataServer = nullptr;
+  libXpertMass::MassDataClient *mpa_massDataClient = nullptr;
+  libXpertMass::MassDataServer *mpa_massDataServer = nullptr;
 
   // The map that relates each MS run data set with the corresponding ms run
   // data set table view window.
@@ -448,4 +448,4 @@ class ProgramWindow : public QMainWindow
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
