@@ -51,7 +51,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -316,4 +316,4 @@ SaveToGraphicsFileDlg::formatItemChanged(int index)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
