@@ -49,7 +49,7 @@
 #include "BasePlotCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -102,4 +102,4 @@ class SaveToGraphicsFileDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
