@@ -46,7 +46,7 @@
 #include "Application.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -207,4 +207,4 @@ SavitzkyGolayFilterParamsDlg::applyPushButtonClicked()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
