@@ -51,7 +51,7 @@
 #include <pappsomspp/processing/filters/savgolfilter.h>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -97,4 +97,4 @@ class SavitzkyGolayFilterParamsDlg : public QDialog
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
