@@ -52,7 +52,7 @@
 #include "TaskMonitorCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -757,4 +757,4 @@ TaskMonitorCompositeWidget::craftStringIfFormattedText(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
