@@ -48,12 +48,12 @@
 #include "ProgramWindow.hpp"
 #include "TicXicChromDriftSpecColorMapWnd.hpp"
 #include "TicXicChromDriftSpecColorMapPlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -461,4 +461,4 @@ TicXicChromDriftSpecColorMapWnd::finishedIntegratingToDtRt(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
