@@ -49,7 +49,7 @@
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToRtDt.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -101,4 +101,4 @@ class TicXicChromDriftSpecColorMapWnd : public BaseColorMapPlotWnd
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
