@@ -53,7 +53,7 @@
 #include "TicXicChromMassSpecColorMapWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -709,4 +709,4 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
