@@ -48,12 +48,12 @@
 #include "ProgramWindow.hpp"
 #include "TicXicChromMassSpecColorMapWnd.hpp"
 #include "TicXicChromMassSpecColorMapPlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -410,4 +410,4 @@ TicXicChromMassSpecColorMapWnd::finishedIntegratingToRtMz(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
