@@ -49,7 +49,7 @@
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -102,4 +102,4 @@ class TicXicChromMassSpecColorMapWnd : public BaseColorMapPlotWnd
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
