@@ -51,7 +51,7 @@
 #include "TicXicChromTracePlotWnd.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -785,4 +785,4 @@ TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
