@@ -50,12 +50,12 @@
 #include "ProgramWindow.hpp"
 #include "TicXicChromTracePlotWnd.hpp"
 #include "TicXicChromTracePlotCompositeWidget.hpp"
-#include "ColorSelector.hpp"
+#include <libXpertMassGui/ColorSelector.hpp>
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -240,7 +240,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   // At this point, we need to get a color for the plot.
   // Set true to ask that the color be selected randomly if no color is
   // available.
-  QColor plot_color = libmassgui::ColorSelector::getColor(true);
+  QColor plot_color = libXpertMassGui::ColorSelector::getColor(true);
 
   // Now we should document the mz integration parameters in the processing flow
   // that is mapped to the graph in such a way that the default mz integration
@@ -653,4 +653,4 @@ TicXicChromTracePlotWnd::integrateToDtRt(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
