@@ -61,7 +61,7 @@
 #include "gui/ProgramWindow.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -127,7 +127,7 @@ printConfig(const QString &execName)
 }
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
 
 
 int
@@ -137,7 +137,7 @@ main(int argc, char **argv)
   Q_INIT_RESOURCE(minexpert2);
 
   // Qt stuff starts here.
-  msxps::minexpert::Application application(argc, argv, "minexpert2");
+  MsXpS::minexpert::Application application(argc, argv, "minexpert2");
 
   QCommandLineParser parser;
   parser.setApplicationDescription("mineXpert2");
@@ -148,8 +148,8 @@ main(int argc, char **argv)
   parser.process(application);
   QString file_name;
 
-  msxps::minexpert::ProgramWindow *main_window_p =
-    new msxps::minexpert::ProgramWindow(nullptr, "mineXpert2");
+  MsXpS::minexpert::ProgramWindow *main_window_p =
+    new MsXpS::minexpert::ProgramWindow(nullptr, "mineXpert2");
   main_window_p->show();
 
   // Store the program window pointer to the Application instance so that we can
