@@ -31,7 +31,7 @@
  */
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -777,4 +777,4 @@ QString gplLegalDisclaimerLiabilitySections(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
