@@ -37,7 +37,7 @@
 #include "AnalysisPreferences.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -231,4 +231,4 @@ AnalysisPreferences::toString() const
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
