@@ -47,7 +47,7 @@
 #include <cmath>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -339,7 +339,7 @@ BaseMsRunDataSetTreeNodeVisitor::checkDtRange(
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
-          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+          pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -453,4 +453,4 @@ BaseMsRunDataSetTreeNodeVisitor::shouldSilenceFeedback()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
