@@ -51,7 +51,7 @@
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -95,4 +95,4 @@ class DriftSpectrumTreeNodeCombinerVisitor
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
