@@ -51,7 +51,7 @@
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -96,4 +96,4 @@ class IntensityTreeNodeCombinerVisitor : public BaseMsRunDataSetTreeNodeVisitor
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
