@@ -52,7 +52,7 @@
 #include "MassDataIntegratorTask.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -195,4 +195,4 @@ MassDataIntegratorTask::integrateToDtRt(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
