@@ -63,7 +63,7 @@
 #include "QualifiedMassSpectrumVectorMassDataIntegratorToRtDt.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -117,4 +117,4 @@ class MassDataIntegratorTask : public QObject
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
