@@ -45,11 +45,11 @@
 
 
 int massSpecDataFileLoaderSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MassSpecDataFileLoaderSPtr>(
-    "msxps::minexpert::MassSpecDataFileLoaderSPtr");
+  qRegisterMetaType<MsXpS::minexpert::MassSpecDataFileLoaderSPtr>(
+    "MsXpS::minexpert::MassSpecDataFileLoaderSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -272,4 +272,4 @@ MassSpecDataFileLoader::loadingEnded()
 }
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
