@@ -54,7 +54,7 @@
 #include "MsRunDataSet.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -163,8 +163,8 @@ typedef std::shared_ptr<const MassSpecDataFileLoader>
   MassSpecDataFileLoaderCstSPtr;
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(msxps::minexpert::MassSpecDataFileLoaderSPtr)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MassSpecDataFileLoaderSPtr)
 extern int massSpecDataFileLoaderSPtrMetaTypeId;
