@@ -53,7 +53,7 @@
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -137,4 +137,4 @@ class MassSpectrumTreeNodeCombinerVisitor
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
