@@ -52,23 +52,23 @@
 #include "MsRunDataSet.hpp"
 
 
-int msRunDataSetMetaTypeId = qRegisterMetaType<msxps::minexpert::MsRunDataSet>(
-  "msxps::minexpert::MsRunDataSet");
+int msRunDataSetMetaTypeId = qRegisterMetaType<MsXpS::minexpert::MsRunDataSet>(
+  "MsXpS::minexpert::MsRunDataSet");
 
 int msRunDataSetPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunDataSet *>(
-    "msxps::minexpert::MsRunDataSetPtr");
+  qRegisterMetaType<MsXpS::minexpert::MsRunDataSet *>(
+    "MsXpS::minexpert::MsRunDataSetPtr");
 
 int msRunDataSetSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunDataSetSPtr>(
-    "msxps::minexpert::MsRunDataSetSPtr");
+  qRegisterMetaType<MsXpS::minexpert::MsRunDataSetSPtr>(
+    "MsXpS::minexpert::MsRunDataSetSPtr");
 
 int msRunDataSetCstSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunDataSetCstSPtr>(
-    "msxps::minexpert::MsRunDataSetCstSPtr");
+  qRegisterMetaType<MsXpS::minexpert::MsRunDataSetCstSPtr>(
+    "MsXpS::minexpert::MsRunDataSetCstSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -350,7 +350,7 @@ MsRunDataSet::mapMassSpectrum(
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
-          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+          pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -482,4 +482,4 @@ MsRunDataSet::treeNodeIteratorRangeForRtRange(double start, double end) const
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
