@@ -56,7 +56,7 @@
 #include "globals.hpp"
 #include "MsRunDataSetStats.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -189,17 +189,17 @@ class MsRunDataSet : public QObject
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunDataSet)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSet)
 extern int msRunDataSetMetaTypeId;
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunDataSet *)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSet *)
 extern int msRunDataSetPtrMetaTypeId;
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunDataSetSPtr)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSetSPtr)
 extern int msRunDataSetSPtrMetaTypeId;
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunDataSetCstSPtr)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSetCstSPtr)
 extern int msRunDataSetCstSPtrMetaTypeId;
