@@ -46,7 +46,7 @@
 #include "globals.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -435,8 +435,11 @@ MsRunDataSetStats::incrementStatistics(
 
   std::vector<double> bins;
 
+  // qDebug() << "Crafting bins for mass spectrum with size:" <<
+  //     mass_spectrum.size();
+
   int binCount = spectrumBins(mass_spectrum, bins);
-  if(mass_spectrum.size() > 1 && binCount == 0)
+  if(mass_spectrum.size() > 1 && !binCount)
     qFatal("Programming error.");
 
   double sum;
@@ -786,4 +789,4 @@ MsRunDataSetStats::toString() const
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
