@@ -49,7 +49,7 @@
 #include "globals.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 
 namespace minexpert
@@ -148,4 +148,4 @@ class MsRunDataSetStats
 
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
