@@ -65,15 +65,15 @@
 
 
 int msRunDataSetTreeMassDataIntegratorToRtMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunDataSetTreeMassDataIntegratorToRt>(
-    "msxps::minexpert::MsRunDataSetTreeMassDataIntegratorToRt");
+  qRegisterMetaType<MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRt>(
+    "MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRt");
 
 int msRunDataSetTreeMassDataIntegratorToRtSPtrMetaTypeId = qRegisterMetaType<
-  msxps::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr>(
-  "msxps::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr");
+  MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr>(
+  "MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -729,4 +729,4 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
