@@ -50,7 +50,7 @@
 #include "MassDataIntegrator.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -105,10 +105,10 @@ class MsRunDataSetTreeMassDataIntegratorToRt : public MassDataIntegrator
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunDataSetTreeMassDataIntegratorToRt)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRt)
 extern int msRunDataSetTreeMassDataIntegratorMetaTypeId;
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunDataSetTreeMassDataIntegratorToRtSPtr)
 extern int msRunDataSetTreeMassDataIntegratorSPtrMetaTypeId;
