@@ -45,15 +45,15 @@
 #include "MsRunProber.hpp"
 
 
-int MsRunProberMetaTypeId = qRegisterMetaType<msxps::minexpert::MsRunProber>(
-  "msxps::minexpert::MsRunProber");
+int MsRunProberMetaTypeId = qRegisterMetaType<MsXpS::minexpert::MsRunProber>(
+  "MsXpS::minexpert::MsRunProber");
 
 int MsRunProberSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::MsRunProberSPtr>(
-    "msxps::minexpert::MsRunProberSPtr");
+  qRegisterMetaType<MsXpS::minexpert::MsRunProberSPtr>(
+    "MsXpS::minexpert::MsRunProberSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -93,8 +93,6 @@ MsRunProber::isReadMsRunFullyInMemory() const
 bool
 MsRunProber::shouldStop() const
 {
-  qDebug() << "20240529";
-
   return m_isOperationCancelled;
 }
 
@@ -103,7 +101,7 @@ MsRunProber::cancelOperation()
 {
   m_isOperationCancelled = true;
 
-  qDebug() << "20240529 - Cancellation asked, setting m_isOperationCancelled "
+  qDebug() << "Cancellation asked, setting m_isOperationCancelled "
               "to true and emitting cancelOperationSignal ";
 
   emit cancelOperationSignal();
@@ -112,4 +110,4 @@ MsRunProber::cancelOperation()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
