@@ -48,7 +48,7 @@
 #include "globals.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -215,11 +215,11 @@ typedef std::shared_ptr<MsRunProber> MsRunProberSPtr;
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunProber)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunProber)
 extern int MsRunProberMetaTypeId;
 
-Q_DECLARE_METATYPE(msxps::minexpert::MsRunProberSPtr)
+Q_DECLARE_METATYPE(MsXpS::minexpert::MsRunProberSPtr)
 extern int MsRunProberSPtrMetaTypeId;
