@@ -49,7 +49,7 @@
 #include "MsRunStatisticsTreeNodeVisitor.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -223,4 +223,4 @@ MsRunStatisticsTreeNodeVisitor::visit(const pappso::MsRunDataSetTreeNode &node)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
