@@ -52,7 +52,7 @@
 #include "MsRunDataSetStats.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -90,4 +90,4 @@ class MsRunStatisticsTreeNodeVisitor : public BaseMsRunDataSetTreeNodeVisitor
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
