@@ -45,7 +45,7 @@
 #include "MultiTreeNodeCombinerVisitor.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -186,4 +186,4 @@ MultiTreeNodeCombinerVisitor::addVisitor(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
