@@ -48,7 +48,7 @@
 #include "ProcessingStep.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -65,7 +65,7 @@ ProcessingFlow::ProcessingFlow(MsRunDataSetCstSPtr ms_run_data_set_csp)
 }
 
 ProcessingFlow::ProcessingFlow(const ProcessingFlow &other)
-  : std::vector<msxps::minexpert::ProcessingStepCstSPtr>(),
+  : std::vector<MsXpS::minexpert::ProcessingStepCstSPtr>(),
     mcsp_msRunDataSet(other.mcsp_msRunDataSet),
     m_defaultMzIntegrationParams(other.m_defaultMzIntegrationParams),
     m_defaultMsFragmentationSpec(other.m_defaultMsFragmentationSpec)
@@ -936,4 +936,4 @@ ProcessingFlow::toString(int offset, const QString &spacer) const
 } // namespace minexpert
 
 
-} // namespace msxps
+} // namespace MsXpS
