@@ -52,7 +52,7 @@
 #include "MsFragmentationSpec.hpp"
 #include "ProcessingStep.hpp"
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -145,4 +145,4 @@ class ProcessingFlow : public std::vector<ProcessingStepCstSPtr>
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
