@@ -47,7 +47,7 @@
 #include "ProcessingStep.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -437,4 +437,4 @@ ProcessingStep::toString(int offset, const QString &spacer) const
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
