@@ -53,7 +53,7 @@
 /////////////////////// Local includes
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -134,4 +134,4 @@ class ProcessingType
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
