@@ -49,15 +49,15 @@
 #include <pappsomspp/processing/combiners/integrationscoperhomb.h>
 
 int qualifiedMassSpectrumVectorMassDataIntegratorMetaTypeId = qRegisterMetaType<
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator>(
-  "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator");
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator>(
+  "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegrator");
 
 int qualMassSpecVecMassDataIntegratorSPtrMetaTypeId = qRegisterMetaType<
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr>(
-  "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr");
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr>(
+  "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -917,7 +917,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
-          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+          pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -1036,7 +1036,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
     {
       QVariant ion_mobility_variant_value =
         qualified_mass_spectrum_csp->getParameterValue(
-          pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+          pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
       if(ion_mobility_variant_value.isValid())
         {
@@ -1107,4 +1107,4 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkRtRange(
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
