@@ -55,16 +55,16 @@
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToDtMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt>(
-    "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt");
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt>(
+    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt");
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToDtSPtrMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr>(
-    "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr");
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr>(
+    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -316,7 +316,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
               // spectrum.
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
-                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+                  pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
               if(ion_mobility_variant_value.isValid())
                 {
@@ -350,7 +350,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
                   ion_mobility_variant_value =
                     qualified_mass_spectrum_csp->getParameterValue(
                       pappso::QualifiedMassSpectrumParameter::
-                        TimsFrameIonMobOneOverK0Begin);
+                        IonMobOneOverK0Begin);
 
                   if(!ion_mobility_variant_value.isValid())
                     {
@@ -545,4 +545,4 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDt::integrate()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
