@@ -52,7 +52,7 @@
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -96,13 +96,13 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToDt
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDt)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToDtMetaTypeId;
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtSPtr)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToDtSPtrMetaTypeId;
