@@ -57,18 +57,18 @@
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz>(
-    "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz");
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz>(
+    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz");
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtrMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::
+    MsXpS::minexpert::
       QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtr>(
-    "msxps::minexpert::"
+    "MsXpS::minexpert::"
     "QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMzSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -495,7 +495,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
               // spectrum.
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
-                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+                  pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
               if(ion_mobility_variant_value.isValid())
                 {
@@ -529,7 +529,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
                   ion_mobility_variant_value =
                     qualified_mass_spectrum_csp->getParameterValue(
                       pappso::QualifiedMassSpectrumParameter::
-                        TimsFrameIonMobOneOverK0Begin);
+                        IonMobOneOverK0Begin);
 
                   if(!ion_mobility_variant_value.isValid())
                     {
@@ -1092,7 +1092,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
             {
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
-                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+                  pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
               if(!ion_mobility_variant_value.isValid())
                 {
@@ -1490,4 +1490,4 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
 }
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
