@@ -57,16 +57,16 @@
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToMzMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz>(
-    "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz");
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz>(
+    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz");
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToMzSPtrMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr>(
-    "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr");
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr>(
+    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -409,7 +409,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
             {
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
-                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+                  pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
               if(ion_mobility_variant_value.isValid())
                 {
@@ -843,7 +843,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
                 {
                   QVariant ion_mobility_variant_value =
                     qualified_mass_spectrum_csp->getParameterValue(
-                      pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+                      pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
                   if(ion_mobility_variant_value.isValid())
                     {
@@ -970,4 +970,4 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
