@@ -52,7 +52,7 @@
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -98,13 +98,13 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToMz
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMz)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToMzMetaTypeId;
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToMzSPtr)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToMzSPtrMetaTypeId;
