@@ -52,7 +52,7 @@
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -96,13 +96,13 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToRt
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRt)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRt)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToRtMetaTypeId;
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtSPtr)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtSPtr)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToRtSPtrMetaTypeId;
