@@ -56,17 +56,17 @@
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToRtDtMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt>(
-    "msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt");
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt>(
+    "MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt");
 
 int qualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtrMetaTypeId =
   qRegisterMetaType<
-    msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr>(
-    "msxps::minexpert::"
+    MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr>(
+    "MsXpS::minexpert::"
     "QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -394,7 +394,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
               // spectrum.
               QVariant ion_mobility_variant_value =
                 qualified_mass_spectrum_csp->getParameterValue(
-                  pappso::QualifiedMassSpectrumParameter::TimsIonMobScanOneOverK0);
+                  pappso::QualifiedMassSpectrumParameter::IonMobOneOverK0);
 
               if(ion_mobility_variant_value.isValid())
                 {
@@ -428,7 +428,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
                   ion_mobility_variant_value =
                     qualified_mass_spectrum_csp->getParameterValue(
                       pappso::QualifiedMassSpectrumParameter::
-                        TimsFrameIonMobOneOverK0Begin);
+                        IonMobOneOverK0Begin);
 
                   if(!ion_mobility_variant_value.isValid())
                     {
@@ -735,4 +735,4 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
