@@ -50,7 +50,7 @@
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -132,13 +132,13 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToRtDt
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDt)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToRtDtMetaTypeId;
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtr)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToRtDtSPtrMetaTypeId;
