@@ -50,7 +50,7 @@
 #include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -97,13 +97,13 @@ class QualifiedMassSpectrumVectorMassDataIntegratorToTicInt
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
 
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicInt)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicInt)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToTicIntMetaTypeId;
 
 Q_DECLARE_METATYPE(
-  msxps::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtr)
+  MsXpS::minexpert::QualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtr)
 extern int qualifiedMassSpectrumVectorMassDataIntegratorToTicIntSPtrMetaTypeId;
