@@ -51,7 +51,7 @@
 #include "BaseMsRunDataSetTreeNodeVisitor.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -91,4 +91,4 @@ class TicChromTreeNodeCombinerVisitor : public BaseMsRunDataSetTreeNodeVisitor
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
