@@ -45,11 +45,11 @@
 
 
 int ticChromatogramFromMassSpecDataFileSPtrMetaTypeId =
-  qRegisterMetaType<msxps::minexpert::TicChromatogramFromMassSpecDataFileSPtr>(
-    "msxps::minexpert::TicChromatogramFromMassSpecDataFileSPtr");
+  qRegisterMetaType<MsXpS::minexpert::TicChromatogramFromMassSpecDataFileSPtr>(
+    "MsXpS::minexpert::TicChromatogramFromMassSpecDataFileSPtr");
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -205,4 +205,4 @@ TicChromatogramFromMassSpecDataFile::loadingEnded()
 }
 
 } // namespace minexpert
-} // namespace msxps
+} // namespace MsXpS
