@@ -51,7 +51,7 @@
 #include "globals.hpp"
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -490,4 +490,4 @@ pointerAsString(void *pointer)
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
