@@ -62,7 +62,7 @@
    */
 
 
-namespace msxps
+namespace MsXpS
 {
 namespace minexpert
 {
@@ -86,8 +86,8 @@ enum MassType
  * When creating JavaScript objects, define which kind of entity is being
  * created.
  *
- * \sa msXpSlibmassgui::ScriptingWnd
- * \sa msXpSlibmassgui::ScriptingObjectTreeWidgetItem
+ * \sa msXpSlibXpertMassGui::ScriptingWnd
+ * \sa msXpSlibXpertMassGui::ScriptingObjectTreeWidgetItem
  */
 enum ScriptEntityType
 {
@@ -156,4 +156,4 @@ QString pointerAsString(void *pointer);
 
 } // namespace minexpert
 
-} // namespace msxps
+} // namespace MsXpS
